@@ -88,6 +88,8 @@ COMPLETED = "Completed"
 FAILED = "Failed"
 TIMED_OUT = "Timed Out"
 DEAD = "Dead"
+INITIATED = "Initiated"
+QUEUED = "Queued"
 REPLICAS = "replicas"
 METRICS = "metrics"
 INTENT_CLASSIFIER_METRICS = "intentClassifierPerformance"
