@@ -183,7 +183,7 @@ def print_projects_table(projects: Dict[Text, Any]):
                 str(data[NUMBER_OF_EXAMPLES]),
                 str(data[NUMBER_OF_INTENTS]),
                 str(data[NUMBER_OF_MODELS]),
-                data[LANGUAGE]
+                ", ".join(data[LANGUAGE])
         )
     console.print(table)
 
